@@ -1,11 +1,11 @@
 package App::Gitc::UserLookup::LocalGroup;
-{
-  $App::Gitc::UserLookup::LocalGroup::VERSION = '0.58';
-}
 
 use strict;
 use warnings;
 
+# ABSTRACT: App::Gitc::Util helper
+our $VERSION = '0.60'; # VERSION
+
 use App::Gitc::Util qw( project_config );
 
 # Users are local users in a specific group.
@@ -23,15 +23,15 @@ __END__
 
 =head1 NAME
 
-App::Gitc::UserLookup::LocalGroup
+App::Gitc::UserLookup::LocalGroup - App::Gitc::Util helper
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 AUTHOR
 
-Grant Street Group
+Grant Street Group <developers@grantstreet.com>
 
 =head1 COPYRIGHT AND LICENSE
 
